@@ -7,6 +7,28 @@ GameCenter pages. This data includes, but is not limited to, game
 schedules, scores, rosters and play-by-play data for every preseason,
 regular season and postseason game dating back to 2009.
 
+Here is a small teaser that shows how to use nfldb to find the top five
+passers in the 2012 regular season:
+
+    #!python
+    import nfldb
+
+    db = nfldb.connect()
+    q = nfldb.Query(db)
+
+    q.game(season_year=2012, season_type='Regular')
+    for pp in q.sort('passing_yds').limit(5).as_aggregate():
+        print pp.player, pp.passing_yds
+
+And the output is:
+
+    [andrew@Liger ~] python2 top-five.py 
+    Drew Brees (NO, QB) 5177
+    Matthew Stafford (DET, QB) 4965
+    Tony Romo (DAL, QB) 4903
+    Tom Brady (NE, QB) 4799
+    Matt Ryan (ATL, QB) 4719
+
 In theory, both `nfldb` and `nflgame` provide access to the same data.
 The difference is in the execution. In order to search data in nflgame,
 a large JSON file needs to be read from disk and loaded into Python
@@ -30,6 +52,9 @@ nfldb can be used in conjunction with
 [nflvid](https://pypi.python.org/pypi/nflvid)
 to
 [search and watch NFL game footage](http://goo.gl/1qSwJw).
+
+If you need help, please join us at our IRC channel `#nflgame` on
+FreeNode.
 """
 from __future__ import absolute_import, division, print_function
 
